# Django Admin Logs Viewer

A Django admin extension for displaying log files directly from the admin panel.  

## 1. Documentation
- [Usage Guide](https://aleksanderwojsz.github.io/django-admin-logs-viewer/docs/category/usage)  
- [Contributing](https://aleksanderwojsz.github.io/django-admin-logs-viewer/docs/category/contributions)

## 2. Features
- Supports multiple nested logs directories
- Parsing based on regex
- Use of different parser for each directory
- Shows errors since last login
- Server-side filtering
- Dark theme support
- Saves you clicks by automatically going down if directory contains only one subdirectory and no files.
- ${\color{red}C}{\color{orange}o}{\color{yellow}l}{\color{green}o}{\color{blue}r}{\color{purple}f}{\color{pink}u}{\color{teal}l}$ logs!

## 3. Demo:

https://github.com/user-attachments/assets/45ae361d-a8e6-4943-b6ee-1895efa2185d

https://github.com/user-attachments/assets/32891853-13d7-4362-bfe4-75faad4a99b7
